utils

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 14, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DispatchMsg added in v1.1.0

func DispatchMsg(msg tea.Msg) tea.Cmd

func NormaliseCodeFences

func NormaliseCodeFences(content string) string

NormaliseCodeFences ensures code blocks and diff lines are not unnecessarily indented. It removes all leading whitespace from code fence markers and diff lines, while preserving internal indentation of the code/diff content.

func OpenEditor

func OpenEditor(path string) error

OpenEditor opens the specified file in the user's preferred text editor.

func RemoveCodeFences

func RemoveCodeFences(message string) string

RemoveCodeFences removes markdown code fences from a given message string.

Types

This section is empty.

Jump to