Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NormaliseCodeFences ¶
NormaliseCodeFences ensures code blocks and diff lines are not unnecessarily indented. It removes all leading whitespace from code fence markers and diff lines, while preserving internal indentation of the code/diff content.
func OpenEditor ¶
OpenEditor opens the specified file in the user's preferred text editor.
func RemoveCodeFences ¶
RemoveCodeFences removes markdown code fences from a given message string.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.